==> grid-helpers-1.4.6-20251008.143357-1-sources.jar: com/flowingcode/vaadin/addons/gridhelpers/GridRadioSelectionColumn.java <==
/*-
 * #%L
 * Grid Helpers Add-on
 * %%
 * Copyright (C) 2022 - 2024 Flowing Code
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */

package com.flowingcode.vaadin.addons.gridhelpers;

import com.vaadin.flow.component.Component;
import com.vaadin.flow.component.grid.Grid;
import com.vaadin.flow.component.HasStyle;
import com.vaadin.flow.component.Synchronize;
import com.vaadin.flow.component.Tag;
import com.vaadin.flow.component.dependency.JsModule;
import com.vaadin.flow.component.dependency.Uses;
import com.vaadin.flow.component.radiobutton.RadioButtonGroup;

/**
 * Server side implementation for the flow specific grid radio selection column.
 */
@Tag("grid-flow-radio-selection-column")
@JsModule("@vaadin/polymer-legacy-adapter/style-modules.js")
@JsModule("./fcGridHelper/grid-flow-radio-selection-column.js")
@Uses(RadioButtonGroup.class)
// Indirectly ensure @NpmPackage(value = "@vaadin/polymer-legacy-adapter", version = "x.x.x")
@Uses(Grid.class)
public class GridRadioSelectionColumn extends Component implements HasStyle {

  /**
   * Sets this column's frozen state.
   *
   * @param frozen whether to freeze or unfreeze this column
   */
  public void setFrozen(boolean frozen) {
    getElement().setProperty("frozen", frozen);
  }

  /**
   * Gets the this column's frozen state.
   *
   * @return whether this column is frozen
   */
  @Synchronize("frozen-changed")
  public boolean isFrozen() {
    return getElement().getProperty("frozen", false);
  }

}

==> grid-helpers-2.0.0-20251203.180538-2-sources.jar: com/flowingcode/vaadin/addons/gridhelpers/GridRadioSelectionColumn.java <==
/*-
 * #%L
 * Grid Helpers Add-on
 * %%
 * Copyright (C) 2022 - 2024 Flowing Code
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */

package com.flowingcode.vaadin.addons.gridhelpers;

import com.vaadin.flow.component.Component;
import com.vaadin.flow.component.grid.Grid;
import com.vaadin.flow.component.HasStyle;
import com.vaadin.flow.component.Synchronize;
import com.vaadin.flow.component.Tag;
import com.vaadin.flow.component.dependency.JsModule;
import com.vaadin.flow.component.dependency.Uses;
import com.vaadin.flow.component.radiobutton.RadioButtonGroup;

/**
 * Server side implementation for the flow specific grid radio selection column.
 */
@Tag("grid-flow-radio-selection-column")
@JsModule("./fcGridHelper/grid-flow-radio-selection-column.js")
@Uses(RadioButtonGroup.class)
// Indirectly ensure @NpmPackage(value = "@vaadin/polymer-legacy-adapter", version = "x.x.x")
// and @JsModule("@vaadin/polymer-legacy-adapter/style-modules.js")
@Uses(Grid.class)
public class GridRadioSelectionColumn extends Component implements HasStyle {

  /**
   * Sets this column's frozen state.
   *
   * @param frozen whether to freeze or unfreeze this column
   */
  public void setFrozen(boolean frozen) {
    getElement().setProperty("frozen", frozen);
  }

  /**
   * Gets the this column's frozen state.
   *
   * @return whether this column is frozen
   */
  @Synchronize("frozen-changed")
  public boolean isFrozen() {
    return getElement().getProperty("frozen", false);
  }

}
